@@ -4,10 +4,10 @@ from typing import List, Optional
 from flair.data import Sentence, Span
 
 from revizor.utils import (
-    _get_article_from_spans,
     _get_brand_from_spans,
     _get_model_from_spans,
     _get_type_from_spans,
+    _get_vendor_code_from_spans,
 )
 
 
@@ -16,7 +16,7 @@ class Product:
     type: Optional[str]
     brand: Optional[str]
     model: Optional[str]
-    article: Optional[str]
+    vendor_code: Optional[str]
 
     spans: List[Span]
     sentence: Sentence
@@ -28,7 +28,7 @@ class Product:
             type=_get_type_from_spans(text, spans),
             brand=_get_brand_from_spans(text, spans),
             model=_get_model_from_spans(text, spans),
-            article=_get_article_from_spans(text, spans),
+            vendor_code=_get_vendor_code_from_spans(text, spans),
             spans=spans,
             sentence=sentence,
         )
